==> zio-aws-finspacedata_3-5.17.155.2-sources.jar: zio/aws/finspacedata/model/DeletePermissionGroupResponse.scala <==
package zio.aws.finspacedata.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.finspacedata.model.primitives.PermissionGroupId
import scala.jdk.CollectionConverters.*
final case class DeletePermissionGroupResponse(
    permissionGroupId: Option[PermissionGroupId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse = {
    import DeletePermissionGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse
      .builder()
      .optionallyWith(
        permissionGroupId.map(value =>
          PermissionGroupId.unwrap(value): java.lang.String
        )
      )(_.permissionGroupId)
      .build()
  }
  def asReadOnly
      : zio.aws.finspacedata.model.DeletePermissionGroupResponse.ReadOnly =
    zio.aws.finspacedata.model.DeletePermissionGroupResponse
      .wrap(buildAwsValue())
}
object DeletePermissionGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.finspacedata.model.DeletePermissionGroupResponse =
      zio.aws.finspacedata.model
        .DeletePermissionGroupResponse(permissionGroupId.map(value => value))
    def permissionGroupId: Option[PermissionGroupId]
    def getPermissionGroupId: ZIO[Any, AwsError, PermissionGroupId] =
      AwsError.unwrapOptionField("permissionGroupId", permissionGroupId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse
  ) extends zio.aws.finspacedata.model.DeletePermissionGroupResponse.ReadOnly {
    override val permissionGroupId: Option[PermissionGroupId] = scala
      .Option(impl.permissionGroupId())
      .map(value =>
        zio.aws.finspacedata.model.primitives.PermissionGroupId(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse
  ): zio.aws.finspacedata.model.DeletePermissionGroupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-finspacedata_3-5.17.195.3-sources.jar: zio/aws/finspacedata/model/DeletePermissionGroupResponse.scala <==
package zio.aws.finspacedata.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.finspacedata.model.primitives.PermissionGroupId
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeletePermissionGroupResponse(
    permissionGroupId: Optional[PermissionGroupId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse = {
    import DeletePermissionGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse
      .builder()
      .optionallyWith(
        permissionGroupId.map(value =>
          PermissionGroupId.unwrap(value): java.lang.String
        )
      )(_.permissionGroupId)
      .build()
  }
  def asReadOnly
      : zio.aws.finspacedata.model.DeletePermissionGroupResponse.ReadOnly =
    zio.aws.finspacedata.model.DeletePermissionGroupResponse
      .wrap(buildAwsValue())
}
object DeletePermissionGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.finspacedata.model.DeletePermissionGroupResponse =
      zio.aws.finspacedata.model
        .DeletePermissionGroupResponse(permissionGroupId.map(value => value))
    def permissionGroupId: Optional[PermissionGroupId]
    def getPermissionGroupId: ZIO[Any, AwsError, PermissionGroupId] =
      AwsError.unwrapOptionField("permissionGroupId", permissionGroupId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse
  ) extends zio.aws.finspacedata.model.DeletePermissionGroupResponse.ReadOnly {
    override val permissionGroupId: Optional[PermissionGroupId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.permissionGroupId())
        .map(value =>
          zio.aws.finspacedata.model.primitives.PermissionGroupId(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.finspacedata.model.DeletePermissionGroupResponse
  ): zio.aws.finspacedata.model.DeletePermissionGroupResponse.ReadOnly =
    new Wrapper(impl)
}
